Class: Musa::Scales::AlteredScaleKind Private

Inherits:
ScaleKind show all
Defined in:
lib/musa-dsl/music/scale_kinds/melodic_minor/altered_scale_kind.rb

Overview

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

Altered scale kind (seventh mode of melodic minor).

AlteredScaleKind defines the Altered scale (also called Super Locrian, Diminished Whole Tone, or Altered Dominant), the seventh mode of the melodic minor scale. It's the quintessential scale for altered dominant chords in jazz.

Pitch Structure

7 diatonic degrees plus extended harmony:

Scale Degrees (lowercase for diminished quality):

  • i (tonic): Root (0 semitones)
  • ii (supertonic): Minor second (1 semitone) ← b9
  • iii (mediant): Minor third (3 semitones) ← #9 (enharmonic)
  • iv (subdominant): Major third (4 semitones) ← b11 (3rd of chord)
  • v (dominant): Diminished fifth (6 semitones) ← b5/#11
  • vi (submediant): Minor sixth (8 semitones) ← #5/b13
  • vii (subtonic): Minor seventh (10 semitones) ← b7

All Alterations Present

Contains all possible alterations of a dominant chord:

  • b9, #9 (altered 9ths)
  • #11/b5 (altered 11th/5th)
  • b13/#5 (altered 13th/5th)

Musical Character

The Altered scale:

  • Maximum tension for dominant chords
  • Used over 7alt, 7#9, 7b9#11, etc.
  • Essential in bebop and modern jazz
  • Creates strong resolution to tonic

Usage

g_alt = Scales[:et12][440.0][:altered][67]
g_alt.tonic  # G (67)
g_alt.ii     # Ab (68) - b9
g_alt.iii    # Bb (70) - #9
g_alt.v      # Db (73) - b5

Constant Summary collapse

@@pitches =

This classvariable is part of a private API. You should avoid using this classvariable if possible, as it may be removed or be changed in the future.

[{ functions: %i[i _1 tonic first],
pitch: 0 },
             { functions: %i[ii _2 supertonic second],
pitch: 1 },
             { functions: %i[iii _3 mediant third],
pitch: 3 },
             { functions: %i[iv _4 subdominant fourth],
pitch: 4 },
             { functions: %i[v _5 dominant fifth],
pitch: 6 },
             { functions: %i[vi _6 submediant sixth],
pitch: 8 },
             { functions: %i[vii _7 subtonic seventh],
pitch: 10 },
             { functions: %i[viii _8 eighth],
pitch: 12 },
             { functions: %i[ix _9 ninth],
pitch: 12 + 1 },
             { functions: %i[x _10 tenth],
pitch: 12 + 3 },
             { functions: %i[xi _11 eleventh],
pitch: 12 + 4 },
             { functions: %i[xii _12 twelfth],
pitch: 12 + 6 },
             { functions: %i[xiii _13 thirteenth],
pitch: 12 + 8 }].freeze

Class Method Summary collapse

Constructor Details

This class inherits a constructor from Musa::Scales::ScaleKind

Class Method Details

.gradesObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



94
95
96
# File 'lib/musa-dsl/music/scale_kinds/melodic_minor/altered_scale_kind.rb', line 94

def grades
  7
end

.idObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



98
99
100
# File 'lib/musa-dsl/music/scale_kinds/melodic_minor/altered_scale_kind.rb', line 98

def id
  :altered
end

.pitchesObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



90
91
92
# File 'lib/musa-dsl/music/scale_kinds/melodic_minor/altered_scale_kind.rb', line 90

def pitches
  @@pitches
end