Class: Musa::Scales::NeapolitanMajorScaleKind Private

Inherits:
ScaleKind show all
Defined in:
lib/musa-dsl/music/scale_kinds/ethnic/neapolitan_major_scale_kind.rb

Overview

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

Neapolitan major scale kind.

NeapolitanMajorScaleKind defines the Neapolitan major scale, a major scale with a lowered second degree, combining the Neapolitan coloring with a brighter major upper structure.

Pitch Structure

7 diatonic degrees plus extended harmony:

Scale Degrees (uppercase for major quality):

  • I (tonic): Root (0 semitones)
  • II (supertonic): Minor second (1 semitone) ← NEAPOLITAN (b2)
  • III (mediant): Minor third (3 semitones)
  • IV (subdominant): Perfect fourth (5 semitones)
  • V (dominant): Perfect fifth (7 semitones)
  • VI (submediant): Major sixth (9 semitones)
  • VII (leading): Major seventh (11 semitones)

Relationship to Melodic Minor

Neapolitan major = Melodic minor with lowered 2nd

Musical Character

The Neapolitan major scale:

  • Exotic but brighter than Neapolitan minor
  • Combines Phrygian darkness with major brightness
  • Used in classical and contemporary music
  • Unique harmonic possibilities

Usage

c_neap_maj = Scales[:et12][440.0][:neapolitan_major][60]
c_neap_maj.tonic  # C (60)
c_neap_maj.II     # Db (61) - minor second (Neapolitan)
c_neap_maj.VI     # A (69) - major sixth
c_neap_maj.VII    # B (71) - leading tone

Constant Summary collapse

@@pitches =

This classvariable is part of a private API. You should avoid using this classvariable if possible, as it may be removed or be changed in the future.

[{ functions: %i[I _1 tonic first],
pitch: 0 },
             { functions: %i[II _2 supertonic second],
pitch: 1 },
             { functions: %i[III _3 mediant third],
pitch: 3 },
             { functions: %i[IV _4 subdominant fourth],
pitch: 5 },
             { functions: %i[V _5 dominant fifth],
pitch: 7 },
             { functions: %i[VI _6 submediant sixth],
pitch: 9 },
             { functions: %i[VII _7 leading seventh],
pitch: 11 },
             { functions: %i[VIII _8 eighth],
pitch: 12 },
             { functions: %i[IX _9 ninth],
pitch: 12 + 1 },
             { functions: %i[X _10 tenth],
pitch: 12 + 3 },
             { functions: %i[XI _11 eleventh],
pitch: 12 + 5 },
             { functions: %i[XII _12 twelfth],
pitch: 12 + 7 },
             { functions: %i[XIII _13 thirteenth],
pitch: 12 + 9 }].freeze

Class Method Summary collapse

Constructor Details

This class inherits a constructor from Musa::Scales::ScaleKind

Class Method Details

.gradesObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



90
91
92
# File 'lib/musa-dsl/music/scale_kinds/ethnic/neapolitan_major_scale_kind.rb', line 90

def grades
  7
end

.idObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



94
95
96
# File 'lib/musa-dsl/music/scale_kinds/ethnic/neapolitan_major_scale_kind.rb', line 94

def id
  :neapolitan_major
end

.pitchesObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



86
87
88
# File 'lib/musa-dsl/music/scale_kinds/ethnic/neapolitan_major_scale_kind.rb', line 86

def pitches
  @@pitches
end