Class: Musa::Scales::NeapolitanMinorScaleKind
- Defined in:
- lib/musa-dsl/music/scale_kinds/ethnic/neapolitan_minor_scale_kind.rb
Overview
Neapolitan minor scale kind.
NeapolitanMinorScaleKind defines the Neapolitan minor scale, a harmonic minor scale with a lowered second degree, named after the Neapolitan school of opera in the 18th century.
Pitch Structure
7 diatonic degrees plus extended harmony:
Scale Degrees (lowercase for minor quality):
- i (tonic): Root (0 semitones)
- ii (supertonic): Minor second (1 semitone) ← NEAPOLITAN (b2)
- iii (mediant): Minor third (3 semitones)
- iv (subdominant): Perfect fourth (5 semitones)
- v (dominant): Perfect fifth (7 semitones)
- vi (submediant): Minor sixth (8 semitones)
- vii (leading): Major seventh (11 semitones)
Relationship to Harmonic Minor
Neapolitan minor = Harmonic minor with lowered 2nd
Musical Character
The Neapolitan minor scale:
- Dark, dramatic, operatic
- The Neapolitan sixth chord (bII) is characteristic
- Used in classical and film music
- Strong resolution tendency to tonic
Usage
a_neap_min = Scales[:et12][440.0][:neapolitan_minor][69]
a_neap_min.tonic # A (69)
a_neap_min.ii # Bb (70) - minor second (Neapolitan)
a_neap_min.vii # G# (80) - leading tone
Constant Summary collapse
- @@pitches =
[{ functions: %i[i _1 tonic first], pitch: 0 }, { functions: %i[ii _2 supertonic second], pitch: 1 }, { functions: %i[iii _3 mediant third], pitch: 3 }, { functions: %i[iv _4 subdominant fourth], pitch: 5 }, { functions: %i[v _5 dominant fifth], pitch: 7 }, { functions: %i[vi _6 submediant sixth], pitch: 8 }, { functions: %i[vii _7 leading seventh], pitch: 11 }, { functions: %i[viii _8 eighth], pitch: 12 }, { functions: %i[ix _9 ninth], pitch: 12 + 1 }, { functions: %i[x _10 tenth], pitch: 12 + 3 }, { functions: %i[xi _11 eleventh], pitch: 12 + 5 }, { functions: %i[xii _12 twelfth], pitch: 12 + 7 }, { functions: %i[xiii _13 thirteenth], pitch: 12 + 8 }].freeze
Class Method Summary collapse
Constructor Details
This class inherits a constructor from Musa::Scales::ScaleKind
Class Method Details
.grades ⇒ Object
89 90 91 |
# File 'lib/musa-dsl/music/scale_kinds/ethnic/neapolitan_minor_scale_kind.rb', line 89 def grades 7 end |
.id ⇒ Object
93 94 95 |
# File 'lib/musa-dsl/music/scale_kinds/ethnic/neapolitan_minor_scale_kind.rb', line 93 def id :neapolitan_minor end |
.pitches ⇒ Object
85 86 87 |
# File 'lib/musa-dsl/music/scale_kinds/ethnic/neapolitan_minor_scale_kind.rb', line 85 def pitches @@pitches end |